@@ -81,12 +81,15 @@ class MiApi:
 
     def transaction_meta(self, program: str, transaction: Optional[str]) -> Union[MiTransactionMetadata, None]:
         program_meta = self.program_meta(program)
+        
+        if not len(program_meta.transactions):
+            return None
 
         for record in program_meta.transactions:
-            if record.transaction == transaction:
+            if record.transaction == transaction: #type: ignore
                 return record
-        else:
-            return None
+            
+        return None
 
 
 @lru_cache(100)
@@ -140,7 +143,7 @@ def mi_meta(endpoint: str, program: Optional[str] = None, transaction: Optional[
                     program
                 ).content
             ).transactions
-            if row.transaction == transaction
+            if row.transaction == transaction #type: ignore
         ][0]
 
     else:
@@ -154,10 +157,10 @@ def mi_api_execute(endpoint: str, program: str, transaction: str, **kwargs) -> M
     "returncols" is a string with comma seperated column names, that defines which coulumns will
     be returned.
     
-    :param endpoint - The name of the endpoint
-    :param program - The M3 program
-    :param metadata - The program transactions
-    :param **kwargs - The input for the transaction '''
+    :param endpoint    - The name of the endpoint
+    :param program     - The M3 program
+    :param transaction - The program transactions
+    :param **kwargs    - The input for the transaction '''
 
     return mi_parse_execute(
         mi_request_execute(
