@@ -68,7 +68,7 @@ def mi_endpoint_list() -> List[Endpoint]:
         Endpoint(
             name = config[section].name.split('.')[1],
             host = config[section]['host'],
-            port = config[section]['port'],
+            port = int(config[section]['port']),
             usr = config[section]['usr'],
             pwd = keyring.get_password(
                 SERVICE_ID,
