@@ -97,7 +97,7 @@ def mi_request_execute(host: str, port: int, usr: str, pwd:str, program: str, tr
     :param transaction - The program transaction
     :param **kwargs - Keyword arguments to be passed to the API
         The maxrecs keyword will set the maximum number of return records.
-        maxrecs=-1 will return all records'''
+        maxrecs=0 will return all records'''
 
     param_str = dict_to_param_str(kwargs)
     url = f'http://{host}:{port}/m3api-rest/execute/{program}/{transaction}{param_str}'
